"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def resume(
    hub, ctx, auto_scaling_group_name: str, scaling_processes: List = None
) -> None:
    r"""
    **Autogenerated function**

    Resumes the specified suspended auto scaling processes, or all suspended process, for the specified Auto Scaling group. For more information, see Suspending and resuming scaling processes in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        scaling_processes(List, optional): One or more of the following processes:    Launch     Terminate     AddToLoadBalancer     AlarmNotification     AZRebalance     HealthCheck     InstanceRefresh     ReplaceUnhealthy     ScheduledActions    If you omit this parameter, all processes are specified. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.process.resume(ctx, auto_scaling_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.process.resume auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="resume_processes",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ScalingProcesses": scaling_processes,
        },
    )


async def suspend(
    hub, ctx, auto_scaling_group_name: str, scaling_processes: List = None
) -> None:
    r"""
    **Autogenerated function**

    Suspends the specified auto scaling processes, or all processes, for the specified Auto Scaling group. If you suspend either the Launch or Terminate process types, it can prevent other process types from functioning properly. For more information, see Suspending and resuming scaling processes in the Amazon EC2 Auto Scaling User Guide. To resume processes that have been suspended, call the ResumeProcesses API.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        scaling_processes(List, optional): One or more of the following processes:    Launch     Terminate     AddToLoadBalancer     AlarmNotification     AZRebalance     HealthCheck     InstanceRefresh     ReplaceUnhealthy     ScheduledActions    If you omit this parameter, all processes are specified. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.process.suspend(ctx, auto_scaling_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.process.suspend auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="suspend_processes",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ScalingProcesses": scaling_processes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def abort(
    hub, ctx, document_id: str, version_id: str, authentication_token: str = None
) -> None:
    r"""
    **Autogenerated function**

    Aborts the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload. The client should make this call only when it no longer intends to upload the document version, or fails to do so.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        version_id(str): The ID of the version.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.document.version.upload.abort(
                ctx, document_id=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.document.version.upload.abort document_id=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="abort_document_version_upload",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "VersionId": version_id,
        },
    )


async def initiate(
    hub,
    ctx,
    parent_folder_id: str,
    authentication_token: str = None,
    id_: str = None,
    name: str = None,
    content_created_timestamp: str = None,
    content_modified_timestamp: str = None,
    content_type: str = None,
    document_size_in_bytes: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new document object and version object. The client specifies the parent folder ID and name of the document to upload. The ID is optionally specified when creating a new version of an existing document. This is the first step to upload a document. Next, upload the document to the URL returned from the call, and then call UpdateDocumentVersion. To cancel the document upload, call AbortDocumentVersionUpload.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        id_(str, optional): The ID of the document. Defaults to None.
        name(str, optional): The name of the document. Defaults to None.
        content_created_timestamp(str, optional): The timestamp when the content of the document was originally created. Defaults to None.
        content_modified_timestamp(str, optional): The timestamp when the content of the document was modified. Defaults to None.
        content_type(str, optional): The content type of the document. Defaults to None.
        document_size_in_bytes(int, optional): The size of the document, in bytes. Defaults to None.
        parent_folder_id(str): The ID of the parent folder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.document.version.upload.initiate(
                ctx, parent_folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.document.version.upload.initiate parent_folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="initiate_document_version_upload",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "Id": id_,
            "Name": name,
            "ContentCreatedTimestamp": content_created_timestamp,
            "ContentModifiedTimestamp": content_modified_timestamp,
            "ContentType": content_type,
            "DocumentSizeInBytes": document_size_in_bytes,
            "ParentFolderId": parent_folder_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, workload_id: str, lens_aliases: List) -> None:
    r"""
    **Autogenerated function**

    Associate a lens to a workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_aliases(List): List of lens aliases to associate or disassociate with a workload. Identify a lens using its LensSummary$LensAlias.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.lens.init.associate(
                ctx, workload_id=value, lens_aliases=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.lens.init.associate workload_id=value, lens_aliases=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="associate_lenses",
        op_kwargs={"WorkloadId": workload_id, "LensAliases": lens_aliases},
    )


async def disassociate(hub, ctx, workload_id: str, lens_aliases: List) -> None:
    r"""
    **Autogenerated function**

    Disassociate a lens from a workload.  The AWS Well-Architected Framework lens (wellarchitected) cannot be removed from a workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_aliases(List): List of lens aliases to associate or disassociate with a workload. Identify a lens using its LensSummary$LensAlias.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.lens.init.disassociate(
                ctx, workload_id=value, lens_aliases=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.lens.init.disassociate workload_id=value, lens_aliases=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="disassociate_lenses",
        op_kwargs={"WorkloadId": workload_id, "LensAliases": lens_aliases},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    List the available lenses.

    Args:
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.lens.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.lens.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_lenses",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    time_period: Dict,
    filter_: Dict = None,
    data_type: List = None,
    next_token: str = None,
    max_results: int = None,
    sort_by: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves attribute data along with aggregate utilization and savings data for a given time period. This doesn't support granular or grouped data (daily/monthly) in response. You can't retrieve data by dates in a single response similar to GetSavingsPlanUtilization, but you have the option to make multiple calls to GetSavingsPlanUtilizationDetails by providing individual dates. You can use GetDimensionValues in SAVINGS_PLANS to determine the possible dimension values.   GetSavingsPlanUtilizationDetails internally groups data by SavingsPlansArn.

    Args:
        time_period(Dict): The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can't be used as an End date.
        filter_(Dict, optional): Filters Savings Plans utilization coverage data for active Savings Plans dimensions. You can filter data with the following dimensions:    LINKED_ACCOUNT     SAVINGS_PLAN_ARN     REGION     PAYMENT_OPTION     INSTANCE_TYPE_FAMILY     GetSavingsPlansUtilizationDetails uses the same Expression object as the other operations, but only AND is supported among each dimension. Defaults to None.
        data_type(List, optional): The data type. Defaults to None.
        next_token(str, optional): The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.
        max_results(int, optional): The number of items to be returned in a response. The default is 20, with a minimum value of 1. Defaults to None.
        sort_by(Dict, optional): The value by which you want to sort the data. The following values are supported for Key:    UtilizationPercentage     TotalCommitment     UsedCommitment     UnusedCommitment     NetSavings     AmortizedRecurringCommitment     AmortizedUpfrontCommitment    Supported values for SortOrder are ASCENDING or DESCENDING. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.saving_plan.utilization.detail.get_all(
                ctx, time_period=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.saving_plan.utilization.detail.get_all time_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_savings_plans_utilization_details",
        op_kwargs={
            "TimePeriod": time_period,
            "Filter": filter_,
            "DataType": data_type,
            "NextToken": next_token,
            "MaxResults": max_results,
            "SortBy": sort_by,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Applies tags to an AWS OpsWorks for Chef Automate or AWS OpsWorks for Puppet Enterprise server, or to server backups.

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of a resource to which you want to apply tags. For example, arn:aws:opsworks-cm:us-west-2:123456789012:server/test-owcm-server/EXAMPLE-66b0-4196-8274-d1a2bEXAMPLE.
        tags(List): A map that contains tag keys and tag values to attach to AWS OpsWorks-CM servers or backups.   The key cannot be empty.   The key can be a maximum of 127 characters, and can contain only Unicode letters, numbers, or separators, or the following special characters: + - = . _ : /    The value can be a maximum 255 characters, and contain only Unicode letters, numbers, or separators, or the following special characters: + - = . _ : /    Leading and trailing white spaces are trimmed from both the key and value.   A maximum of 50 user-applied tags is allowed for any AWS OpsWorks-CM server or backup.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes specified tags from an AWS OpsWorks-CM server or backup.

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of a resource from which you want to remove tags. For example, arn:aws:opsworks-cm:us-west-2:123456789012:server/test-owcm-server/EXAMPLE-66b0-4196-8274-d1a2bEXAMPLE.
        tag_keys(List): The keys of tags that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    reserved_elasticsearch_instance_offering_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists available reserved Elasticsearch instance offerings.

    Args:
        reserved_elasticsearch_instance_offering_id(str, optional): The offering identifier filter value. Use this parameter to show only the available offering that matches the specified reservation identifier. Defaults to None.
        max_results(int, optional): Set this value to limit the number of results returned. If not specified, defaults to 100. Defaults to None.
        next_token(str, optional): NextToken should be sent in case if earlier API call produced result containing NextToken. It is used for pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.reserved_elasticsearch_instance.offering.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.reserved_elasticsearch_instance.offering.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_reserved_elasticsearch_instance_offerings",
        op_kwargs={
            "ReservedElasticsearchInstanceOfferingId": reserved_elasticsearch_instance_offering_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def purchase(
    hub,
    ctx,
    reserved_elasticsearch_instance_offering_id: str,
    reservation_name: str,
    instance_count: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to purchase reserved Elasticsearch instances.

    Args:
        reserved_elasticsearch_instance_offering_id(str): The ID of the reserved Elasticsearch instance offering to purchase.
        reservation_name(str): A customer-specified identifier to track this reservation.
        instance_count(int, optional): The number of Elasticsearch instances to reserve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.reserved_elasticsearch_instance.offering.purchase(
                ctx, reserved_elasticsearch_instance_offering_id=value, reservation_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.reserved_elasticsearch_instance.offering.purchase reserved_elasticsearch_instance_offering_id=value, reservation_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="purchase_reserved_elasticsearch_instance_offering",
        op_kwargs={
            "ReservedElasticsearchInstanceOfferingId": reserved_elasticsearch_instance_offering_id,
            "ReservationName": reservation_name,
            "InstanceCount": instance_count,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    portfolio_id: str,
    product_id: str,
    parameters: str,
    type_: str,
    idempotency_token: str,
    accept_language: str = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a constraint. A delegated admin is authorized to invoke this command.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        product_id(str): The product identifier.
        parameters(str): The constraint parameters, in JSON format. The syntax depends on the constraint type as follows:  LAUNCH  You are required to specify either the RoleArn or the LocalRoleName but can't use both. Specify the RoleArn property as follows:  {"RoleArn" : "arn:aws:iam::123456789012:role/LaunchRole"}  Specify the LocalRoleName property as follows:  {"LocalRoleName": "SCBasicLaunchRole"}  If you specify the LocalRoleName property, when an account uses the launch constraint, the IAM role with that name in the account will be used. This allows launch-role constraints to be account-agnostic so the administrator can create fewer resources per shared account.  The given role name must exist in the account used to create the launch constraint and the account of the user who launches a product with this launch constraint.  You cannot have both a LAUNCH and a STACKSET constraint. You also cannot have more than one LAUNCH constraint on a product and portfolio.  NOTIFICATION  Specify the NotificationArns property as follows:  {"NotificationArns" : ["arn:aws:sns:us-east-1:123456789012:Topic"]}   RESOURCE_UPDATE  Specify the TagUpdatesOnProvisionedProduct property as follows:  {"Version":"2.0","Properties":{"TagUpdateOnProvisionedProduct":"String"}}  The TagUpdatesOnProvisionedProduct property accepts a string value of ALLOWED or NOT_ALLOWED.  STACKSET  Specify the Parameters property as follows:  {"Version": "String", "Properties": {"AccountList": [ "String" ], "RegionList": [ "String" ], "AdminRole": "String", "ExecutionRole": "String"}}  You cannot have both a LAUNCH and a STACKSET constraint. You also cannot have more than one STACKSET constraint on a product and portfolio. Products with a STACKSET constraint will launch an AWS CloudFormation stack set.  TEMPLATE  Specify the Rules property. For more information, see Template Constraint Rules.  .
        type_(str): The type of constraint.    LAUNCH     NOTIFICATION     RESOURCE_UPDATE     STACKSET     TEMPLATE   .
        description(str, optional): The description of the constraint. Defaults to None.
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.constraint.init.create(
                ctx,
                portfolio_id=value,
                product_id=value,
                parameters=value,
                type_=value,
                idempotency_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.constraint.init.create portfolio_id=value, product_id=value, parameters=value, type_=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_constraint",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "ProductId": product_id,
            "Parameters": parameters,
            "Type": type_,
            "Description": description,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified constraint. A delegated admin is authorized to invoke this command.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The identifier of the constraint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.constraint.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.constraint.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_constraint",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_},
    )


async def describe(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified constraint.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The identifier of the constraint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.constraint.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.constraint.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_constraint",
        op_kwargs={"AcceptLanguage": accept_language, "Id": id_},
    )


async def update(
    hub,
    ctx,
    id_: str,
    accept_language: str = None,
    description: str = None,
    parameters: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified constraint.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The identifier of the constraint.
        description(str, optional): The updated description of the constraint. Defaults to None.
        parameters(str, optional): The constraint parameters, in JSON format. The syntax depends on the constraint type as follows:  LAUNCH  You are required to specify either the RoleArn or the LocalRoleName but can't use both. Specify the RoleArn property as follows:  {"RoleArn" : "arn:aws:iam::123456789012:role/LaunchRole"}  Specify the LocalRoleName property as follows:  {"LocalRoleName": "SCBasicLaunchRole"}  If you specify the LocalRoleName property, when an account uses the launch constraint, the IAM role with that name in the account will be used. This allows launch-role constraints to be account-agnostic so the administrator can create fewer resources per shared account.  The given role name must exist in the account used to create the launch constraint and the account of the user who launches a product with this launch constraint.  You cannot have both a LAUNCH and a STACKSET constraint. You also cannot have more than one LAUNCH constraint on a product and portfolio.  NOTIFICATION  Specify the NotificationArns property as follows:  {"NotificationArns" : ["arn:aws:sns:us-east-1:123456789012:Topic"]}   RESOURCE_UPDATE  Specify the TagUpdatesOnProvisionedProduct property as follows:  {"Version":"2.0","Properties":{"TagUpdateOnProvisionedProduct":"String"}}  The TagUpdatesOnProvisionedProduct property accepts a string value of ALLOWED or NOT_ALLOWED.  STACKSET  Specify the Parameters property as follows:  {"Version": "String", "Properties": {"AccountList": [ "String" ], "RegionList": [ "String" ], "AdminRole": "String", "ExecutionRole": "String"}}  You cannot have both a LAUNCH and a STACKSET constraint. You also cannot have more than one STACKSET constraint on a product and portfolio. Products with a STACKSET constraint will launch an AWS CloudFormation stack set.  TEMPLATE  Specify the Rules property. For more information, see Template Constraint Rules.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.constraint.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.constraint.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_constraint",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Id": id_,
            "Description": description,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, index_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a search index.

    Args:
        index_name(str): The index name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.index.describe(ctx, index_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.index.describe index_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_index",
        op_kwargs={"indexName": index_name},
    )


async def search(
    hub,
    ctx,
    query_string: str,
    index_name: str = None,
    next_token: str = None,
    max_results: int = None,
    query_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The query search index.

    Args:
        index_name(str, optional): The search index name. Defaults to None.
        query_string(str): The search query string.
        next_token(str, optional): The token used to get the next set of results, or null if there are no additional results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        query_version(str, optional): The query version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.index.search(ctx, query_string=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.index.search query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="search_index",
        op_kwargs={
            "indexName": index_name,
            "queryString": query_string,
            "nextToken": next_token,
            "maxResults": max_results,
            "queryVersion": query_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of phone numbers that are opted out, meaning you cannot send SMS messages to them. The results for ListPhoneNumbersOptedOut are paginated, and each page returns up to 100 phone numbers. If additional phone numbers are available after the first page of results, then a NextToken string will be returned. To receive the next page, you call ListPhoneNumbersOptedOut again using the NextToken string received from the previous call. When there are no more records to return, NextToken will be null.

    Args:
        next_token(str, optional): A NextToken string is used when you call the ListPhoneNumbersOptedOut action to retrieve additional records that are available after the first page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.phone_number_opted_out.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.phone_number_opted_out.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_phone_numbers_opted_out",
        op_kwargs={"nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, auto_scaling_group_provider: Dict, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new capacity provider. Capacity providers are associated with an Amazon ECS cluster and are used in capacity provider strategies to facilitate cluster auto scaling. Only capacity providers using an Auto Scaling group can be created. Amazon ECS tasks on Fargate use the FARGATE and FARGATE_SPOT capacity providers which are already created and available to all accounts in Regions supported by Fargate.

    Args:
        name(str): The name of the capacity provider. Up to 255 characters are allowed, including letters (upper and lowercase), numbers, underscores, and hyphens. The name cannot be prefixed with "aws", "ecs", or "fargate".
        auto_scaling_group_provider(Dict): The details of the Auto Scaling group for the capacity provider.
        tags(List, optional): The metadata that you apply to the capacity provider to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.capacity_provider.create(
                ctx, name=value, auto_scaling_group_provider=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.capacity_provider.create name=value, auto_scaling_group_provider=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="create_capacity_provider",
        op_kwargs={
            "name": name,
            "autoScalingGroupProvider": auto_scaling_group_provider,
            "tags": tags,
        },
    )


async def delete(hub, ctx, capacity_provider: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified capacity provider.  The FARGATE and FARGATE_SPOT capacity providers are reserved and cannot be deleted. You can disassociate them from a cluster using either the PutClusterCapacityProviders API or by deleting the cluster.  Prior to a capacity provider being deleted, the capacity provider must be removed from the capacity provider strategy from all services. The UpdateService API can be used to remove a capacity provider from a service's capacity provider strategy. When updating a service, the forceNewDeployment option can be used to ensure that any tasks using the Amazon EC2 instance capacity provided by the capacity provider are transitioned to use the capacity from the remaining capacity providers. Only capacity providers that are not associated with a cluster can be deleted. To remove a capacity provider from a cluster, you can either use PutClusterCapacityProviders or delete the cluster.

    Args:
        capacity_provider(str): The short name or full Amazon Resource Name (ARN) of the capacity provider to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.capacity_provider.delete(ctx, capacity_provider=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.capacity_provider.delete capacity_provider=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="delete_capacity_provider",
        op_kwargs={"capacityProvider": capacity_provider},
    )


async def describe_all(
    hub,
    ctx,
    capacity_providers: List = None,
    include: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your capacity providers.

    Args:
        capacity_providers(List, optional): The short name or full Amazon Resource Name (ARN) of one or more capacity providers. Up to 100 capacity providers can be described in an action. Defaults to None.
        include(List, optional): Specifies whether or not you want to see the resource tags for the capacity provider. If TAGS is specified, the tags are included in the response. If this field is omitted, tags are not included in the response. Defaults to None.
        max_results(int, optional): The maximum number of account setting results returned by DescribeCapacityProviders in paginated output. When this parameter is used, DescribeCapacityProviders only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeCapacityProviders request with the returned nextToken value. This value can be between 1 and 10. If this parameter is not used, then DescribeCapacityProviders returns up to 10 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeCapacityProviders request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.capacity_provider.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.capacity_provider.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="describe_capacity_providers",
        op_kwargs={
            "capacityProviders": capacity_providers,
            "include": include,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(hub, ctx, name: str, auto_scaling_group_provider: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the parameters for a capacity provider.

    Args:
        name(str): The name of the capacity provider to update.
        auto_scaling_group_provider(Dict): An object representing the parameters to update for the Auto Scaling group capacity provider.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.capacity_provider.update(
                ctx, name=value, auto_scaling_group_provider=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.capacity_provider.update name=value, auto_scaling_group_provider=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_capacity_provider",
        op_kwargs={
            "name": name,
            "autoScalingGroupProvider": auto_scaling_group_provider,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.global_setting.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.global_setting.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="chime", operation="get_global_settings", op_kwargs={}
    )


async def update_multiple(
    hub, ctx, business_calling: Dict, voice_connector: Dict
) -> None:
    r"""
    **Autogenerated function**

    Updates global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.

    Args:
        business_calling(Dict): The Amazon Chime Business Calling settings.
        voice_connector(Dict): The Amazon Chime Voice Connector settings.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.global_setting.update_multiple(
                ctx, business_calling=value, voice_connector=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.global_setting.update_multiple business_calling=value, voice_connector=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_global_settings",
        op_kwargs={
            "BusinessCalling": business_calling,
            "VoiceConnector": voice_connector,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more tags (key-value pairs) to the specified canary.  Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only resources with certain tag values. Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters. You can use the TagResource action with a canary that already has tags. If you specify a new tag key for the alarm, this tag is appended to the list of tags associated with the alarm. If you specify a tag key that is already associated with the alarm, the new tag value that you specify replaces the previous value for that tag. You can associate as many as 50 tags with a canary.

    Args:
        resource_arn(str): The ARN of the canary that you're adding tags to. The ARN format of a canary is arn:aws:synthetics:Region:account-id:canary:canary-name .
        tags(Dict): The list of key-value pairs to associate with the canary.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from the specified canary.

    Args:
        resource_arn(str): The ARN of the canary that you're removing tags from. The ARN format of a canary is arn:aws:synthetics:Region:account-id:canary:canary-name .
        tag_keys(List): The list of tag keys to remove from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    aggregate_field: str,
    filter_: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the number of events of each event type (issue, scheduled change, and account notification). If no filter is specified, the counts of all events in each category are returned.  This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.

    Args:
        filter_(Dict, optional): Values to narrow the results returned. Defaults to None.
        aggregate_field(str): The only currently supported value is eventTypeCategory.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.event.aggregate.describe_all(ctx, aggregate_field=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.event.aggregate.describe_all aggregate_field=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_event_aggregates",
        op_kwargs={
            "filter": filter_,
            "aggregateField": aggregate_field,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def swap(
    hub,
    ctx,
    source_environment_id: str = None,
    source_environment_name: str = None,
    destination_environment_id: str = None,
    destination_environment_name: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Swaps the CNAMEs of two environments.

    Args:
        source_environment_id(str, optional): The ID of the source environment.  Condition: You must specify at least the SourceEnvironmentID or the SourceEnvironmentName. You may also specify both. If you specify the SourceEnvironmentId, you must specify the DestinationEnvironmentId. . Defaults to None.
        source_environment_name(str, optional): The name of the source environment.  Condition: You must specify at least the SourceEnvironmentID or the SourceEnvironmentName. You may also specify both. If you specify the SourceEnvironmentName, you must specify the DestinationEnvironmentName. . Defaults to None.
        destination_environment_id(str, optional): The ID of the destination environment.  Condition: You must specify at least the DestinationEnvironmentID or the DestinationEnvironmentName. You may also specify both. You must specify the SourceEnvironmentId with the DestinationEnvironmentId. . Defaults to None.
        destination_environment_name(str, optional): The name of the destination environment.  Condition: You must specify at least the DestinationEnvironmentID or the DestinationEnvironmentName. You may also specify both. You must specify the SourceEnvironmentName with the DestinationEnvironmentName. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.cname.swap(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.cname.swap
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="swap_environment_cnames",
        op_kwargs={
            "SourceEnvironmentId": source_environment_id,
            "SourceEnvironmentName": source_environment_name,
            "DestinationEnvironmentId": destination_environment_id,
            "DestinationEnvironmentName": destination_environment_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, upload_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the status of the specified upload.

    Args:
        upload_id(str): The ID of the upload. This value is returned by the UploadEntityDefinitions action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.upload_status.get(ctx, upload_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.upload_status.get upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_upload_status",
        op_kwargs={"uploadId": upload_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Add one or more tags (keys and values) to a specified application. A tag is a label that you optionally define and associate with an application. Tags can help you categorize and manage application in different ways, such as by purpose, owner, environment, or other criteria.  Each tag consists of a required tag key and an associated tag value, both of which you define. A tag key is a general label that acts as a category for more specific tag values. A tag value acts as a descriptor within a tag key.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the application that you want to add one or more tags to.
        tags(List): A list of tags that to add to the application. A tag consists of a required tag key (Key) and an associated tag value (Value). The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove one or more tags (keys and values) from a specified application.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the application that you want to remove one or more tags from.
        tag_keys(List): The tags (tag keys) that you want to remove from the resource. When you specify a tag key, the action removes both that key and its associated tag value. To remove more than one tag from the application, append the TagKeys parameter and argument for each additional tag to remove, separated by an ampersand. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, add_on_type: str, resource_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables an add-on for an Amazon Lightsail resource. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        add_on_type(str): The add-on type to disable.
        resource_name(str): The name of the source resource for which to disable the add-on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.add_on.disable(
                ctx, add_on_type=value, resource_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.add_on.disable add_on_type=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="disable_add_on",
        op_kwargs={"addOnType": add_on_type, "resourceName": resource_name},
    )


async def enable(hub, ctx, resource_name: str, add_on_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Enables or modifies an add-on for an Amazon Lightsail resource. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        resource_name(str): The name of the source resource for which to enable or modify the add-on.
        add_on_request(Dict): An array of strings representing the add-on to enable or modify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.add_on.enable(
                ctx, resource_name=value, add_on_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.add_on.enable resource_name=value, add_on_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="enable_add_on",
        op_kwargs={"resourceName": resource_name, "addOnRequest": add_on_request},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, policy_name: str, target: str) -> None:
    r"""
    **Autogenerated function**

    Attaches the specified policy to the specified principal (certificate or other credential).

    Args:
        policy_name(str): The name of the policy to attach.
        target(str): The identity to which the policy is attached. For example, a thing group or a certificate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.init.attach(ctx, policy_name=value, target=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.init.attach policy_name=value, target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="attach_policy",
        op_kwargs={"policyName": policy_name, "target": target},
    )


async def create(
    hub, ctx, policy_name: str, policy_document: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS IoT policy. The created policy is the default version for the policy. This operation creates a policy version with a version identifier of 1 and sets 1 as the policy's default version.

    Args:
        policy_name(str): The policy name.
        policy_document(str): The JSON document that describes the policy. policyDocument must have a minimum length of 1, with a maximum length of 2048, excluding whitespace.
        tags(List, optional): Metadata which can be used to manage the policy.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.init.create(
                ctx, policy_name=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.init.create policy_name=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_policy",
        op_kwargs={
            "policyName": policy_name,
            "policyDocument": policy_document,
            "tags": tags,
        },
    )


async def delete(hub, ctx, policy_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified policy. A policy cannot be deleted if it has non-default versions or it is attached to any certificate. To delete a policy, use the DeletePolicyVersion API to delete all non-default versions of the policy; use the DetachPrincipalPolicy API to detach the policy from any certificate; and then use the DeletePolicy API to delete the policy. When a policy is deleted using DeletePolicy, its default version is deleted with it.

    Args:
        policy_name(str): The name of the policy to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.init.delete(ctx, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.init.delete policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_policy",
        op_kwargs={"policyName": policy_name},
    )


async def detach(hub, ctx, policy_name: str, target: str) -> None:
    r"""
    **Autogenerated function**

    Detaches a policy from the specified target.

    Args:
        policy_name(str): The policy to detach.
        target(str): The target from which the policy will be detached.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.init.detach(ctx, policy_name=value, target=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.init.detach policy_name=value, target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="detach_policy",
        op_kwargs={"policyName": policy_name, "target": target},
    )


async def get(hub, ctx, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified policy with the policy document of the default version.

    Args:
        policy_name(str): The name of the policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.init.get(ctx, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.init.get policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_policy",
        op_kwargs={"policyName": policy_name},
    )


async def list_all(
    hub, ctx, marker: str = None, page_size: int = None, ascending_order: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your policies.

    Args:
        marker(str, optional): The marker for the next set of results. Defaults to None.
        page_size(int, optional): The result page size. Defaults to None.
        ascending_order(bool, optional): Specifies the order for results. If true, the results are returned in ascending creation order. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_policies",
        op_kwargs={
            "marker": marker,
            "pageSize": page_size,
            "ascendingOrder": ascending_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This implementation of the GET action uses the acl subresource to return the access control list (ACL) of a bucket. To use GET to return the ACL of the bucket, you must have READ_ACP access to the bucket. If READ_ACP permission is granted to the anonymous user, you can return the ACL of the bucket without using an authorization header.  Related Resources     ListObjects

    Args:
        bucket(str): Specifies the S3 bucket whose ACL is being requested.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.acl.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.acl.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_acl",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    acl: str = None,
    access_control_policy: Dict = None,
    content_md5: str = None,
    grant_full_control: str = None,
    grant_read: str = None,
    grant_read_acp: str = None,
    grant_write: str = None,
    grant_write_acp: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the permissions on an existing bucket using access control lists (ACL). For more information, see Using ACLs. To set the ACL of a bucket, you must have WRITE_ACP permission. You can use one of the following two ways to set a bucket's permissions:   Specify the ACL in the request body   Specify permissions using request headers    You cannot specify access permission using both the body and the request headers.  Depending on your application needs, you may choose to set the ACL on a bucket using either the request body or the headers. For example, if you have an existing application that updates a bucket ACL using the request body, then you can continue to use that approach.  Access Permissions  You can set access permissions using one of the following methods:   Specify a canned ACL with the x-amz-acl request header. Amazon S3 supports a set of predefined ACLs, known as canned ACLs. Each canned ACL has a predefined set of grantees and permissions. Specify the canned ACL name as the value of x-amz-acl. If you use this header, you cannot use other access control-specific headers in your request. For more information, see Canned ACL.   Specify access permissions explicitly with the x-amz-grant-read, x-amz-grant-read-acp, x-amz-grant-write-acp, and x-amz-grant-full-control headers. When using these headers, you specify explicit access permissions and grantees (AWS accounts or Amazon S3 groups) who will receive the permission. If you use these ACL-specific headers, you cannot use the x-amz-acl header to set a canned ACL. These parameters map to the set of permissions that Amazon S3 supports in an ACL. For more information, see Access Control List (ACL) Overview. You specify each grantee as a type=value pair, where the type is one of the following:    id – if the value specified is the canonical user ID of an AWS account    uri – if you are granting permissions to a predefined group    emailAddress – if the value specified is the email address of an AWS account  Using email addresses to specify a grantee is only supported in the following AWS Regions:    US East (N. Virginia)   US West (N. California)    US West (Oregon)    Asia Pacific (Singapore)   Asia Pacific (Sydney)   Asia Pacific (Tokyo)   Europe (Ireland)   South America (São Paulo)   For a list of all the Amazon S3 supported Regions and endpoints, see Regions and Endpoints in the AWS General Reference.    For example, the following x-amz-grant-write header grants create, overwrite, and delete objects permission to LogDelivery group predefined by Amazon S3 and two AWS accounts identified by their email addresses.  x-amz-grant-write: uri="http://acs.amazonaws.com/groups/s3/LogDelivery", id="111122223333", id="555566667777"     You can use either a canned ACL or specify access permissions explicitly. You cannot do both.  Grantee Values  You can specify the person (grantee) to whom you're assigning access rights (using request elements) in the following ways:   By the person's ID:  <Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:type="CanonicalUser"><ID><>ID<></ID><DisplayName><>GranteesEmail<></DisplayName> </Grantee>  DisplayName is optional and ignored in the request   By URI:  <Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:type="Group"><URI><>http://acs.amazonaws.com/groups/global/AuthenticatedUsers<></URI></Grantee>    By Email address:  <Grantee xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:type="AmazonCustomerByEmail"><EmailAddress><>Grantees@email.com<></EmailAddress>lt;/Grantee>  The grantee is resolved to the CanonicalUser and, in a response to a GET Object acl request, appears as the CanonicalUser.   Using email addresses to specify a grantee is only supported in the following AWS Regions:    US East (N. Virginia)   US West (N. California)    US West (Oregon)    Asia Pacific (Singapore)   Asia Pacific (Sydney)   Asia Pacific (Tokyo)   Europe (Ireland)   South America (São Paulo)   For a list of all the Amazon S3 supported Regions and endpoints, see Regions and Endpoints in the AWS General Reference.     Related Resources     CreateBucket     DeleteBucket     GetObjectAcl

    Args:
        acl(str, optional): The canned ACL to apply to the bucket. Defaults to None.
        access_control_policy(Dict, optional): Contains the elements that set the ACL permissions for an object per grantee. Defaults to None.
        bucket(str): The bucket to which to apply the ACL.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.  For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        grant_full_control(str, optional): Allows grantee the read, write, read ACP, and write ACP permissions on the bucket. Defaults to None.
        grant_read(str, optional): Allows grantee to list the objects in the bucket. Defaults to None.
        grant_read_acp(str, optional): Allows grantee to read the bucket ACL. Defaults to None.
        grant_write(str, optional): Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also allows deletions and overwrites of those objects. Defaults to None.
        grant_write_acp(str, optional): Allows grantee to write the ACL for the applicable bucket. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.acl.put(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.acl.put bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_acl",
        op_kwargs={
            "ACL": acl,
            "AccessControlPolicy": access_control_policy,
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "GrantFullControl": grant_full_control,
            "GrantRead": grant_read,
            "GrantReadACP": grant_read_acp,
            "GrantWrite": grant_write,
            "GrantWriteACP": grant_write_acp,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    auto_minor_version_upgrade: bool,
    broker_name: str,
    deployment_mode: str,
    engine_type: str,
    engine_version: str,
    host_instance_type: str,
    publicly_accessible: bool,
    users: List,
    authentication_strategy: str = None,
    configuration: Dict = None,
    creator_request_id: str = None,
    encryption_options: Dict = None,
    ldap_server_metadata: Dict = None,
    logs: Dict = None,
    maintenance_window_start_time: Dict = None,
    security_groups: List = None,
    storage_type: str = None,
    subnet_ids: List = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a broker. Note: This API is asynchronous. To create a broker, you must either use the AmazonMQFullAccess IAM policy or include the following EC2 permissions in your IAM policy. ec2:CreateNetworkInterface This permission is required to allow Amazon MQ to create an elastic network interface (ENI) on behalf of your account. ec2:CreateNetworkInterfacePermission This permission is required to attach the ENI to the broker instance. ec2:DeleteNetworkInterface ec2:DeleteNetworkInterfacePermission ec2:DetachNetworkInterface ec2:DescribeInternetGateways ec2:DescribeNetworkInterfaces ec2:DescribeNetworkInterfacePermissions ec2:DescribeRouteTables ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs For more information, see Create an IAM User and Get Your AWS Credentials and Never Modify or Delete the Amazon MQ Elastic Network Interface in the Amazon MQ Developer Guide.

    Args:
        authentication_strategy(str, optional): Optional. The authentication strategy used to secure the broker. The default is SIMPLE. Defaults to None.
        auto_minor_version_upgrade(bool): Enables automatic upgrades to new minor versions for brokers, as new versions are released and supported by Amazon MQ. Automatic upgrades occur during the scheduled maintenance window of the broker or after a manual broker reboot. Set to true by default, if no value is specified.
        broker_name(str): Required. The broker's name. This value must be unique in your AWS account, 1-50 characters long, must contain only letters, numbers, dashes, and underscores, and must not contain white spaces, brackets, wildcard characters, or special characters.
        configuration(Dict, optional): A list of information about the configuration. Defaults to None.
        creator_request_id(str, optional): The unique ID that the requester receives for the created broker. Amazon MQ passes your ID with the API action. Note: We recommend using a Universally Unique Identifier (UUID) for the creatorRequestId. You may omit the creatorRequestId if your application doesn't require idempotency. Defaults to None.
        deployment_mode(str): Required. The broker's deployment mode.
        encryption_options(Dict, optional): Encryption options for the broker. Does not apply to RabbitMQ brokers. Defaults to None.
        engine_type(str): Required. The type of broker engine. Currently, Amazon MQ supports ACTIVEMQ and RABBITMQ.
        engine_version(str): Required. The broker engine's version. For a list of supported engine versions, see Supported engines.
        host_instance_type(str): Required. The broker's instance type.
        ldap_server_metadata(Dict, optional): Optional. The metadata of the LDAP server used to authenticate and authorize connections to the broker. Does not apply to RabbitMQ brokers. Defaults to None.
        logs(Dict, optional): Enables Amazon CloudWatch logging for brokers. Defaults to None.
        maintenance_window_start_time(Dict, optional): The parameters that determine the WeeklyStartTime. Defaults to None.
        publicly_accessible(bool): Enables connections from applications outside of the VPC that hosts the broker's subnets. Set to false by default, if no value is provided.
        security_groups(List, optional): The list of rules (1 minimum, 125 maximum) that authorize connections to brokers. Defaults to None.
        storage_type(str, optional): The broker's storage type. Defaults to None.
        subnet_ids(List, optional): The list of groups that define which subnets and IP ranges the broker can use from different Availability Zones. If you specify more than one subnet, the subnets must be in different Availability Zones. Amazon MQ will not be able to create VPC endpoints for your broker with multiple subnets in the same Availability Zone. A SINGLE_INSTANCE deployment requires one subnet (for example, the default subnet). An ACTIVE_STANDBY_MULTI_AZ Amazon MQ for ActiveMQ deployment requires two subnets. A CLUSTER_MULTI_AZ Amazon MQ for RabbitMQ deployment has no subnet requirements when deployed with public accessibility. Deployment without public accessibility requires at least one subnet. If you specify subnets in a shared VPC for a RabbitMQ broker, the associated VPC to which the specified subnets belong must be owned by your AWS account. Amazon MQ will not be able to create VPC endpoints in VPCs that are not owned by your AWS account. Defaults to None.
        tags(Dict, optional): Create tags when creating the broker. Defaults to None.
        users(List): Required. The list of broker users (persons or applications) who can access queues and topics. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 2-100 characters long. Amazon MQ for RabbitMQ When you create an Amazon MQ for RabbitMQ broker, one and only one administrative user is accepted and created when a broker is first provisioned. All subsequent broker users are created by making RabbitMQ API calls directly to brokers or via the RabbitMQ web console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.init.create(
                ctx,
                auto_minor_version_upgrade=value,
                broker_name=value,
                deployment_mode=value,
                engine_type=value,
                engine_version=value,
                host_instance_type=value,
                publicly_accessible=value,
                users=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.init.create auto_minor_version_upgrade=value, broker_name=value, deployment_mode=value, engine_type=value, engine_version=value, host_instance_type=value, publicly_accessible=value, users=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="create_broker",
        op_kwargs={
            "AuthenticationStrategy": authentication_strategy,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "BrokerName": broker_name,
            "Configuration": configuration,
            "CreatorRequestId": creator_request_id,
            "DeploymentMode": deployment_mode,
            "EncryptionOptions": encryption_options,
            "EngineType": engine_type,
            "EngineVersion": engine_version,
            "HostInstanceType": host_instance_type,
            "LdapServerMetadata": ldap_server_metadata,
            "Logs": logs,
            "MaintenanceWindowStartTime": maintenance_window_start_time,
            "PubliclyAccessible": publicly_accessible,
            "SecurityGroups": security_groups,
            "StorageType": storage_type,
            "SubnetIds": subnet_ids,
            "Tags": tags,
            "Users": users,
        },
    )


async def delete(hub, ctx, broker_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a broker. Note: This API is asynchronous.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.init.delete(ctx, broker_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.init.delete broker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="delete_broker",
        op_kwargs={"BrokerId": broker_id},
    )


async def describe(hub, ctx, broker_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified broker.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.init.describe(ctx, broker_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.init.describe broker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="describe_broker",
        op_kwargs={"BrokerId": broker_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all brokers.

    Args:
        max_results(int, optional): The maximum number of brokers that Amazon MQ can return per page (20 by default). This value must be an integer from 5 to 100. Defaults to None.
        next_token(str, optional): The token that specifies the next page of results Amazon MQ should return. To request the first page, leave nextToken empty. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="list_brokers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def reboot(hub, ctx, broker_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Reboots a broker. Note: This API is asynchronous.

    Args:
        broker_id(str): The unique ID that Amazon MQ generates for the broker.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.init.reboot(ctx, broker_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.init.reboot broker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="reboot_broker",
        op_kwargs={"BrokerId": broker_id},
    )


async def update(
    hub,
    ctx,
    broker_id: str,
    authentication_strategy: str = None,
    auto_minor_version_upgrade: bool = None,
    configuration: Dict = None,
    engine_version: str = None,
    host_instance_type: str = None,
    ldap_server_metadata: Dict = None,
    logs: Dict = None,
    maintenance_window_start_time: Dict = None,
    security_groups: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a pending configuration change to a broker.

    Args:
        authentication_strategy(str, optional): Optional. The authentication strategy used to secure the broker. The default is SIMPLE. Defaults to None.
        auto_minor_version_upgrade(bool, optional): Enables automatic upgrades to new minor versions for brokers, as new versions are released and supported by Amazon MQ. Automatic upgrades occur during the scheduled maintenance window of the broker or after a manual broker reboot. Defaults to None.
        broker_id(str): The unique ID that Amazon MQ generates for the broker.
        configuration(Dict, optional): A list of information about the configuration. Defaults to None.
        engine_version(str, optional): The broker engine version. For a list of supported engine versions, see Supported engines. Defaults to None.
        host_instance_type(str, optional): The broker's host instance type to upgrade to. For a list of supported instance types, see Broker instance types. Defaults to None.
        ldap_server_metadata(Dict, optional): Optional. The metadata of the LDAP server used to authenticate and authorize connections to the broker. Does not apply to RabbitMQ brokers. Defaults to None.
        logs(Dict, optional): Enables Amazon CloudWatch logging for brokers. Defaults to None.
        maintenance_window_start_time(Dict, optional): The parameters that determine the WeeklyStartTime. Defaults to None.
        security_groups(List, optional): The list of security groups (1 minimum, 5 maximum) that authorizes connections to brokers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.init.update(ctx, broker_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.init.update broker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="update_broker",
        op_kwargs={
            "AuthenticationStrategy": authentication_strategy,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "BrokerId": broker_id,
            "Configuration": configuration,
            "EngineVersion": engine_version,
            "HostInstanceType": host_instance_type,
            "LdapServerMetadata": ldap_server_metadata,
            "Logs": logs,
            "MaintenanceWindowStartTime": maintenance_window_start_time,
            "SecurityGroups": security_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    asset_id: str,
    hierarchy_id: str = None,
    traversal_direction: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of associated assets. You can use this operation to do the following:   List child assets associated to a parent asset by a hierarchy that you specify.   List an asset's parent asset.

    Args:
        asset_id(str): The ID of the asset to query.
        hierarchy_id(str, optional): The ID of the hierarchy by which child assets are associated to the asset. To find a hierarchy ID, use the DescribeAsset or DescribeAssetModel operations. This parameter is required if you choose CHILD for traversalDirection. For more information, see Asset hierarchies in the IoT SiteWise User Guide. Defaults to None.
        traversal_direction(str, optional): The direction to list associated assets. Choose one of the following options:    CHILD – The list includes all child assets associated to the asset. The hierarchyId parameter is required if you choose CHILD.    PARENT – The list includes the asset's parent asset.   Default: CHILD . Defaults to None.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.associated_asset.list_all(ctx, asset_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.associated_asset.list_all asset_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="list_associated_assets",
        op_kwargs={
            "assetId": asset_id,
            "hierarchyId": hierarchy_id,
            "traversalDirection": traversal_direction,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, instance_id: str, parent_group_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new user hierarchy group.

    Args:
        name(str): The name of the user hierarchy group. Must not be more than 100 characters.
        parent_group_id(str, optional): The identifier for the parent hierarchy group. The user hierarchy is created at level one if the parent group ID is null. Defaults to None.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.group.init.create(
                ctx, name=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.group.init.create name=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_user_hierarchy_group",
        op_kwargs={
            "Name": name,
            "ParentGroupId": parent_group_id,
            "InstanceId": instance_id,
        },
    )


async def delete(hub, ctx, hierarchy_group_id: str, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing user hierarchy group. It must not be associated with any agents or have any active child groups.

    Args:
        hierarchy_group_id(str): The identifier of the hierarchy group.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.group.init.delete(
                ctx, hierarchy_group_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.group.init.delete hierarchy_group_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="delete_user_hierarchy_group",
        op_kwargs={"HierarchyGroupId": hierarchy_group_id, "InstanceId": instance_id},
    )


async def describe(hub, ctx, hierarchy_group_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified hierarchy group.

    Args:
        hierarchy_group_id(str): The identifier of the hierarchy group.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.group.init.describe(
                ctx, hierarchy_group_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.group.init.describe hierarchy_group_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_user_hierarchy_group",
        op_kwargs={"HierarchyGroupId": hierarchy_group_id, "InstanceId": instance_id},
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides summary information about the hierarchy groups for the specified Amazon Connect instance. For more information about agent hierarchies, see Set Up Agent Hierarchies in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.group.init.list_all(
                ctx, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.group.init.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_user_hierarchy_groups",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    hyper_parameter_tuning_job_name: str,
    hyper_parameter_tuning_job_config: Dict,
    training_job_definition: Dict = None,
    training_job_definitions: List = None,
    warm_start_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a hyperparameter tuning job. A hyperparameter tuning job finds the best version of a model by running many training jobs on your dataset using the algorithm you choose and values for hyperparameters within ranges that you specify. It then chooses the hyperparameter values that result in a model that performs the best, as measured by an objective metric that you choose.

    Args:
        hyper_parameter_tuning_job_name(str): The name of the tuning job. This name is the prefix for the names of all training jobs that this tuning job launches. The name must be unique within the same Amazon Web Services account and Amazon Web Services Region. The name must have 1 to 32 characters. Valid characters are a-z, A-Z, 0-9, and : + = @ _ % - (hyphen). The name is not case sensitive.
        hyper_parameter_tuning_job_config(Dict): The HyperParameterTuningJobConfig object that describes the tuning job, including the search strategy, the objective metric used to evaluate training jobs, ranges of parameters to search, and resource limits for the tuning job. For more information, see How Hyperparameter Tuning Works.
        training_job_definition(Dict, optional): The HyperParameterTrainingJobDefinition object that describes the training jobs that this tuning job launches, including static hyperparameters, input data configuration, output data configuration, resource configuration, and stopping condition. Defaults to None.
        training_job_definitions(List, optional): A list of the HyperParameterTrainingJobDefinition objects launched for this tuning job. Defaults to None.
        warm_start_config(Dict, optional): Specifies the configuration for starting the hyperparameter tuning job using one or more previous tuning jobs as a starting point. The results of previous tuning jobs are used to inform which combinations of hyperparameters to search over in the new tuning job. All training jobs launched by the new hyperparameter tuning job are evaluated by using the objective metric. If you specify IDENTICAL_DATA_AND_ALGORITHM as the WarmStartType value for the warm start configuration, the training job that performs the best in the new tuning job is compared to the best training jobs from the parent tuning jobs. From these, the training job that performs the best as measured by the objective metric is returned as the overall best training job.  All training jobs launched by parent hyperparameter tuning jobs and the new hyperparameter tuning jobs count against the limit of training jobs for the tuning job. . Defaults to None.
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Tags that you specify for the tuning job are also added to all training jobs that the tuning job launches. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.hyper_parameter_tuning_job.create(
                ctx, hyper_parameter_tuning_job_name=value, hyper_parameter_tuning_job_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.hyper_parameter_tuning_job.create hyper_parameter_tuning_job_name=value, hyper_parameter_tuning_job_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_hyper_parameter_tuning_job",
        op_kwargs={
            "HyperParameterTuningJobName": hyper_parameter_tuning_job_name,
            "HyperParameterTuningJobConfig": hyper_parameter_tuning_job_config,
            "TrainingJobDefinition": training_job_definition,
            "TrainingJobDefinitions": training_job_definitions,
            "WarmStartConfig": warm_start_config,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, hyper_parameter_tuning_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a description of a hyperparameter tuning job.

    Args:
        hyper_parameter_tuning_job_name(str): The name of the tuning job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.hyper_parameter_tuning_job.describe(
                ctx, hyper_parameter_tuning_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.hyper_parameter_tuning_job.describe hyper_parameter_tuning_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_hyper_parameter_tuning_job",
        op_kwargs={"HyperParameterTuningJobName": hyper_parameter_tuning_job_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    sort_by: str = None,
    sort_order: str = None,
    name_contains: str = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    status_equals: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of HyperParameterTuningJobSummary objects that describe the hyperparameter tuning jobs launched in your account.

    Args:
        next_token(str, optional): If the result of the previous ListHyperParameterTuningJobs request was truncated, the response includes a NextToken. To retrieve the next set of tuning jobs, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of tuning jobs to return. The default value is 10. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is Name. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.
        name_contains(str, optional): A string in the tuning job name. This filter returns only tuning jobs whose name contains the specified string. Defaults to None.
        creation_time_after(str, optional): A filter that returns only tuning jobs that were created after the specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only tuning jobs that were created before the specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only tuning jobs that were modified after the specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only tuning jobs that were modified before the specified time. Defaults to None.
        status_equals(str, optional): A filter that returns only tuning jobs with the specified status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.hyper_parameter_tuning_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.hyper_parameter_tuning_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_hyper_parameter_tuning_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NameContains": name_contains,
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "StatusEquals": status_equals,
        },
    )


async def stop(hub, ctx, hyper_parameter_tuning_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops a running hyperparameter tuning job and all running training jobs that the tuning job launched. All model artifacts output from the training jobs are stored in Amazon Simple Storage Service (Amazon S3). All data that the training jobs write to Amazon CloudWatch Logs are still available in CloudWatch. After the tuning job moves to the Stopped state, it releases all reserved resources for the tuning job.

    Args:
        hyper_parameter_tuning_job_name(str): The name of the tuning job to stop.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.hyper_parameter_tuning_job.stop(
                ctx, hyper_parameter_tuning_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.hyper_parameter_tuning_job.stop hyper_parameter_tuning_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_hyper_parameter_tuning_job",
        op_kwargs={"HyperParameterTuningJobName": hyper_parameter_tuning_job_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    volume_ids: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the most recent volume modification request for the specified EBS volumes. If a volume has never been modified, some information in the output will be null. If a volume has been modified more than once, the output includes only the most recent modification request. You can also use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the Amazon CloudWatch Events User Guide. For more information, see Monitor the progress of volume modifications in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        volume_ids(List, optional): The IDs of the volumes. Defaults to None.
        filters(List, optional): The filters.    modification-state - The current modification state (modifying | optimizing | completed | failed).    original-iops - The original IOPS rate of the volume.    original-size - The original size of the volume, in GiB.    original-volume-type - The original volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1).    originalMultiAttachEnabled - Indicates whether Multi-Attach support was enabled (true | false).    start-time - The modification start time.    target-iops - The target IOPS rate of the volume.    target-size - The target size of the volume, in GiB.    target-volume-type - The target volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1).    targetMultiAttachEnabled - Indicates whether Multi-Attach support is to be enabled (true | false).    volume-id - The ID of the volume.  . Defaults to None.
        next_token(str, optional): The nextToken value returned by a previous paginated request. Defaults to None.
        max_results(int, optional): The maximum number of results (up to a limit of 500) to be returned in a paginated request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.volume.modification.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.volume.modification.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_volumes_modifications",
        op_kwargs={
            "DryRun": dry_run,
            "VolumeIds": volume_ids,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, distribution_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the timestamp and status of the last cache reset of a specific Amazon Lightsail content delivery network (CDN) distribution.

    Args:
        distribution_name(str, optional): The name of the distribution for which to return the timestamp of the last cache reset. Use the GetDistributions action to get a list of distribution names that you can specify. When omitted, the response includes the latest cache reset timestamp of all your distributions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.latest_cache_reset.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.latest_cache_reset.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_distribution_latest_cache_reset",
        op_kwargs={"distributionName": distribution_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    organization_id: str,
    device_type: str = None,
    device_model: str = None,
    device_operating_system: str = None,
    device_user_agent: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Simulates the effect of the mobile device access rules for the given attributes of a sample access event. Use this method to test the effects of the current set of mobile device access rules for the Amazon WorkMail organization for a particular user's attributes.

    Args:
        organization_id(str): The Amazon WorkMail organization to simulate the access effect for.
        device_type(str, optional): Device type the simulated user will report. Defaults to None.
        device_model(str, optional): Device model the simulated user will report. Defaults to None.
        device_operating_system(str, optional): Device operating system the simulated user will report. Defaults to None.
        device_user_agent(str, optional): Device user agent the simulated user will report. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mobile_device_access.effect.get(
                ctx, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mobile_device_access.effect.get organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="get_mobile_device_access_effect",
        op_kwargs={
            "OrganizationId": organization_id,
            "DeviceType": device_type,
            "DeviceModel": device_model,
            "DeviceOperatingSystem": device_operating_system,
            "DeviceUserAgent": device_user_agent,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "set"


async def create(
    hub,
    ctx,
    resource_set_name: str,
    resource_set_type: str,
    resources: List,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Resource Set.

    Args:
        resource_set_name(str): The name of the ResourceSet to create.
        resource_set_type(str): AWS Resource type of the resources in the ResourceSet.
        resources(List): A list of Resource objects.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.resource.set_.create(
                ctx, resource_set_name=value, resource_set_type=value, resources=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.resource.set.create resource_set_name=value, resource_set_type=value, resources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="create_resource_set",
        op_kwargs={
            "ResourceSetName": resource_set_name,
            "ResourceSetType": resource_set_type,
            "Resources": resources,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, resource_set_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing Resource Set.

    Args:
        resource_set_name(str): The ResourceSet to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.resource.set_.delete(
                ctx, resource_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.resource.set.delete resource_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="delete_resource_set",
        op_kwargs={"ResourceSetName": resource_set_name},
    )


async def get(hub, ctx, resource_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a Resource Set.

    Args:
        resource_set_name(str): The ResourceSet to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.resource.set_.get(
                ctx, resource_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.resource.set.get resource_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="get_resource_set",
        op_kwargs={"ResourceSetName": resource_set_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of Resource Sets.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.resource.set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.resource.set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="list_resource_sets",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, resource_set_name: str, resource_set_type: str, resources: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Resource Set.

    Args:
        resource_set_name(str): The ResourceSet to update.
        resource_set_type(str): AWS Resource Type of the resources in the ResourceSet.
        resources(List): A list of Resource objects.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.resource.set_.update(
                ctx, resource_set_name=value, resource_set_type=value, resources=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.resource.set.update resource_set_name=value, resource_set_type=value, resources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="update_resource_set",
        op_kwargs={
            "ResourceSetName": resource_set_name,
            "ResourceSetType": resource_set_type,
            "Resources": resources,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, resource: str, suggestion_query: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    An auto-complete API for the search functionality in the Amazon SageMaker console. It returns suggestions of possible matches for the property name to use in Search queries. Provides suggestions for HyperParameters, Tags, and Metrics.

    Args:
        resource(str): The name of the Amazon SageMaker resource to search for.
        suggestion_query(Dict, optional): Limits the property names that are included in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.search_suggestion.get_all(ctx, resource=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.search_suggestion.get_all resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="get_search_suggestions",
        op_kwargs={"Resource": resource, "SuggestionQuery": suggestion_query},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assign(hub, ctx, volume_id: str, instance_id: str = None) -> None:
    r"""
    **Autogenerated function**

    Assigns one of the stack's registered Amazon EBS volumes to a specified instance. The volume must first be registered with the stack by calling RegisterVolume. After you register the volume, you must call UpdateVolume to specify a mount point before calling AssignVolume. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        volume_id(str): The volume ID.
        instance_id(str, optional): The instance ID. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.volume.assign(ctx, volume_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.volume.assign volume_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="assign_volume",
        op_kwargs={"VolumeId": volume_id, "InstanceId": instance_id},
    )


async def deregister(hub, ctx, volume_id: str) -> None:
    r"""
    **Autogenerated function**

    Deregisters an Amazon EBS volume. The volume can then be registered by another stack. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        volume_id(str): The AWS OpsWorks Stacks volume ID, which is the GUID that AWS OpsWorks Stacks assigned to the instance when you registered the volume with the stack, not the Amazon EC2 volume ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.volume.deregister(ctx, volume_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.volume.deregister volume_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="deregister_volume",
        op_kwargs={"VolumeId": volume_id},
    )


async def describe_all(
    hub,
    ctx,
    instance_id: str = None,
    stack_id: str = None,
    raid_array_id: str = None,
    volume_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an instance's Amazon EBS volumes.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        instance_id(str, optional): The instance ID. If you use this parameter, DescribeVolumes returns descriptions of the volumes associated with the specified instance. Defaults to None.
        stack_id(str, optional): A stack ID. The action describes the stack's registered Amazon EBS volumes. Defaults to None.
        raid_array_id(str, optional): The RAID array ID. If you use this parameter, DescribeVolumes returns descriptions of the volumes associated with the specified RAID array. Defaults to None.
        volume_ids(List, optional): Am array of volume IDs. If you use this parameter, DescribeVolumes returns descriptions of the specified volumes. Otherwise, it returns a description of every volume. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.volume.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.volume.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_volumes",
        op_kwargs={
            "InstanceId": instance_id,
            "StackId": stack_id,
            "RaidArrayId": raid_array_id,
            "VolumeIds": volume_ids,
        },
    )


async def register(hub, ctx, stack_id: str, ec2_volume_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Registers an Amazon EBS volume with a specified stack. A volume can be registered with only one stack at a time. If the volume is already registered, you must first deregister it by calling DeregisterVolume. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        ec2_volume_id(str, optional): The Amazon EBS volume ID. Defaults to None.
        stack_id(str): The stack ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.volume.register(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.volume.register stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="register_volume",
        op_kwargs={"Ec2VolumeId": ec2_volume_id, "StackId": stack_id},
    )


async def unassign(hub, ctx, volume_id: str) -> None:
    r"""
    **Autogenerated function**

    Unassigns an assigned Amazon EBS volume. The volume remains registered with the stack. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        volume_id(str): The volume ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.volume.unassign(ctx, volume_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.volume.unassign volume_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="unassign_volume",
        op_kwargs={"VolumeId": volume_id},
    )


async def update(
    hub, ctx, volume_id: str, name: str = None, mount_point: str = None
) -> None:
    r"""
    **Autogenerated function**

    Updates an Amazon EBS volume's name or mount point. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        volume_id(str): The volume ID.
        name(str, optional): The new name. Defaults to None.
        mount_point(str, optional): The new mount point. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.volume.update(ctx, volume_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.volume.update volume_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_volume",
        op_kwargs={"VolumeId": volume_id, "Name": name, "MountPoint": mount_point},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def reset(hub, ctx, directory_id: str, user_name: str, new_password: str) -> Dict:
    r"""
    **Autogenerated function**

    Resets the password for any user in your AWS Managed Microsoft AD or Simple AD directory. You can reset the password for any user in your directory with the following exceptions:   For Simple AD, you cannot reset the password for any user that is a member of either the Domain Admins or Enterprise Admins group except for the administrator user.   For AWS Managed Microsoft AD, you can only reset the password for a user that is in an OU based off of the NetBIOS name that you typed when you created your directory. For example, you cannot reset the password for a user in the AWS Reserved OU. For more information about the OU structure for an AWS Managed Microsoft AD directory, see What Gets Created in the AWS Directory Service Administration Guide.

    Args:
        directory_id(str): Identifier of the AWS Managed Microsoft AD or Simple AD directory in which the user resides.
        user_name(str): The user name of the user whose password will be reset.
        new_password(str): The new password that will be reset.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.user_password.reset(
                ctx, directory_id=value, user_name=value, new_password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.user_password.reset directory_id=value, user_name=value, new_password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="reset_user_password",
        op_kwargs={
            "DirectoryId": directory_id,
            "UserName": user_name,
            "NewPassword": new_password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(
    hub,
    ctx,
    response_plan_arn: str,
    client_token: str = None,
    impact: int = None,
    related_items: List = None,
    title: str = None,
    trigger_details: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to start an incident from CloudWatch alarms, EventBridge events, or manually.

    Args:
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.
        impact(int, optional): Defines the impact to the customers. Providing an impact overwrites the impact provided by a response plan.  Possible impacts:     1 - Critical impact, this typically relates to full application failure that impacts many to all customers.     2 - High impact, partial application failure with impact to many customers.    3 - Medium impact, the application is providing reduced service to customers.    4 - Low impact, customer might aren't impacted by the problem yet.    5 - No impact, customers aren't currently impacted but urgent action is needed to avoid impact.  . Defaults to None.
        related_items(List, optional): Add related items to the incident for other responders to use. Related items are AWS resources, external links, or files uploaded to an S3 bucket. . Defaults to None.
        response_plan_arn(str): The Amazon Resource Name (ARN) of the response plan that pre-defines summary, chat channels, SNS topics, runbooks, title, and impact of the incident. .
        title(str, optional): Provide a title for the incident. Providing a title overwrites the title provided by the response plan. . Defaults to None.
        trigger_details(Dict, optional): Details of what created the incident record in Incident Manager. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.incident.init.start(ctx, response_plan_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.incident.init.start response_plan_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="start_incident",
        op_kwargs={
            "clientToken": client_token,
            "impact": impact,
            "relatedItems": related_items,
            "responsePlanArn": response_plan_arn,
            "title": title,
            "triggerDetails": trigger_details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    connector_entity_name: str,
    connector_type: str = None,
    connector_profile_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Provides details regarding the entity used with the connector, with a description of the data model for each entity.

    Args:
        connector_entity_name(str):  The entity name for that connector. .
        connector_type(str, optional):  The type of connector application, such as Salesforce, Amplitude, and so on. . Defaults to None.
        connector_profile_name(str, optional):  The name of the connector profile. The name is unique for each ConnectorProfile in the AWS account. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.entity.describe(
                ctx, connector_entity_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.entity.describe connector_entity_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="describe_connector_entity",
        op_kwargs={
            "connectorEntityName": connector_entity_name,
            "connectorType": connector_type,
            "connectorProfileName": connector_profile_name,
        },
    )


async def list_all(
    hub,
    ctx,
    connector_profile_name: str = None,
    connector_type: str = None,
    entities_path: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the list of available connector entities supported by Amazon AppFlow. For example, you can query Salesforce for Account and Opportunity entities, or query ServiceNow for the Incident entity.

    Args:
        connector_profile_name(str, optional):  The name of the connector profile. The name is unique for each ConnectorProfile in the AWS account, and is used to query the downstream connector. . Defaults to None.
        connector_type(str, optional):  The type of connector, such as Salesforce, Amplitude, and so on. . Defaults to None.
        entities_path(str, optional):  This optional parameter is specific to connector implementation. Some connectors support multiple levels or categories of entities. You can find out the list of roots for such providers by sending a request without the entitiesPath parameter. If the connector supports entities at different roots, this initial request returns the list of roots. Otherwise, this request returns all entities supported by the provider. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.entity.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.entity.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="list_connector_entities",
        op_kwargs={
            "connectorProfileName": connector_profile_name,
            "connectorType": connector_type,
            "entitiesPath": entities_path,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    access_token: str,
    sms_mfa_settings: Dict = None,
    software_token_mfa_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Set the user's multi-factor authentication (MFA) method preference, including which MFA factors are enabled and if any are preferred. Only one factor can be set as preferred. The preferred MFA factor will be used to authenticate a user if multiple factors are enabled. If multiple options are enabled and no preference is set, a challenge to choose an MFA option will be returned during sign in. If an MFA type is enabled for a user, the user will be prompted for MFA during all sign in attempts, unless device tracking is turned on and the device has been trusted. If you would like MFA to be applied selectively based on the assessed risk level of sign in attempts, disable MFA for users and turn on Adaptive Authentication for the user pool.

    Args:
        sms_mfa_settings(Dict, optional): The SMS text message multi-factor authentication (MFA) settings. Defaults to None.
        software_token_mfa_settings(Dict, optional): The time-based one-time password software token MFA settings. Defaults to None.
        access_token(str): The access token for the user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.mfa_preference.set(ctx, access_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.mfa_preference.set access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="set_user_mfa_preference",
        op_kwargs={
            "SMSMfaSettings": sms_mfa_settings,
            "SoftwareTokenMfaSettings": software_token_mfa_settings,
            "AccessToken": access_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, policy_hash_condition: str = None, resource_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified policy.

    Args:
        policy_hash_condition(str, optional): The hash value returned when this policy was set. Defaults to None.
        resource_arn(str, optional): The ARN of the Glue resource for the resource policy to be deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.resource.policy.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.resource.policy.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_resource_policy",
        op_kwargs={
            "PolicyHashCondition": policy_hash_condition,
            "ResourceArn": resource_arn,
        },
    )


async def get_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the resource policies set on individual resources by Resource Access Manager during cross-account permission grants. Also retrieves the Data Catalog resource policy. If you enabled metadata encryption in Data Catalog settings, and you do not have permission on the KMS key, the operation can't return the Data Catalog resource policy.

    Args:
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.
        max_results(int, optional): The maximum size of a list to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.resource.policy.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.resource.policy.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_resource_policies",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def get(hub, ctx, resource_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a specified resource policy.

    Args:
        resource_arn(str, optional): The ARN of the Glue resource for which to retrieve the resource policy. If not supplied, the Data Catalog resource policy is returned. Use GetResourcePolicies to view all existing resource policies. For more information see Specifying Glue Resource ARNs. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.resource.policy.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.resource.policy.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_resource_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def put(
    hub,
    ctx,
    policy_in_json: str,
    resource_arn: str = None,
    policy_hash_condition: str = None,
    policy_exists_condition: str = None,
    enable_hybrid: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the Data Catalog resource policy for access control.

    Args:
        policy_in_json(str): Contains the policy document to set, in JSON format.
        resource_arn(str, optional): Do not use. For internal use only. Defaults to None.
        policy_hash_condition(str, optional): The hash value returned when the previous policy was set using PutResourcePolicy. Its purpose is to prevent concurrent modifications of a policy. Do not use this parameter if no previous policy has been set. Defaults to None.
        policy_exists_condition(str, optional): A value of MUST_EXIST is used to update a policy. A value of NOT_EXIST is used to create a new policy. If a value of NONE or a null value is used, the call does not depend on the existence of a policy. Defaults to None.
        enable_hybrid(str, optional): If 'TRUE', indicates that you are using both methods to grant cross-account access to Data Catalog resources:   By directly updating the resource policy with PutResourePolicy    By using the Grant permissions command on the Amazon Web Services Management Console.   Must be set to 'TRUE' if you have already used the Management Console to grant cross-account access, otherwise the call fails. Default is 'FALSE'. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.resource.policy.put(ctx, policy_in_json=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.resource.policy.put policy_in_json=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="put_resource_policy",
        op_kwargs={
            "PolicyInJson": policy_in_json,
            "ResourceArn": resource_arn,
            "PolicyHashCondition": policy_hash_condition,
            "PolicyExistsCondition": policy_exists_condition,
            "EnableHybrid": enable_hybrid,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, action_name: str, role_arn: str, action_params: Dict, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Defines an action that can be applied to audit findings by using StartAuditMitigationActionsTask. Only certain types of mitigation actions can be applied to specific check names. For more information, see Mitigation actions. Each mitigation action can apply only one type of change.

    Args:
        action_name(str): A friendly name for the action. Choose a friendly name that accurately describes the action (for example, EnableLoggingAction).
        role_arn(str): The ARN of the IAM role that is used to apply the mitigation action.
        action_params(Dict): Defines the type of action and the parameters for that action.
        tags(List, optional): Metadata that can be used to manage the mitigation action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.mitigation_action.create(
                ctx, action_name=value, role_arn=value, action_params=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.mitigation_action.create action_name=value, role_arn=value, action_params=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_mitigation_action",
        op_kwargs={
            "actionName": action_name,
            "roleArn": role_arn,
            "actionParams": action_params,
            "tags": tags,
        },
    )


async def delete(hub, ctx, action_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a defined mitigation action from your AWS account.

    Args:
        action_name(str): The name of the mitigation action that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.mitigation_action.delete(ctx, action_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.mitigation_action.delete action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_mitigation_action",
        op_kwargs={"actionName": action_name},
    )


async def describe(hub, ctx, action_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a mitigation action.

    Args:
        action_name(str): The friendly name that uniquely identifies the mitigation action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.mitigation_action.describe(ctx, action_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.mitigation_action.describe action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_mitigation_action",
        op_kwargs={"actionName": action_name},
    )


async def list_all(
    hub, ctx, action_type: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of all mitigation actions that match the specified filter criteria.

    Args:
        action_type(str, optional): Specify a value to limit the result to mitigation actions with a specific action type. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.mitigation_action.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.mitigation_action.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_mitigation_actions",
        op_kwargs={
            "actionType": action_type,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub, ctx, action_name: str, role_arn: str = None, action_params: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the definition for the specified mitigation action.

    Args:
        action_name(str): The friendly name for the mitigation action. You cannot change the name by using UpdateMitigationAction. Instead, you must delete and recreate the mitigation action with the new name.
        role_arn(str, optional): The ARN of the IAM role that is used to apply the mitigation action. Defaults to None.
        action_params(Dict, optional): Defines the type of action and the parameters for that action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.mitigation_action.update(ctx, action_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.mitigation_action.update action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_mitigation_action",
        op_kwargs={
            "actionName": action_name,
            "roleArn": role_arn,
            "actionParams": action_params,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "ip_set"


async def create(
    hub,
    ctx,
    detector_id: str,
    name: str,
    format_: str,
    location: str,
    activate: bool,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new IPSet, which is called a trusted IP list in the console user interface. An IPSet is a list of IP addresses that are trusted for secure communication with AWS infrastructure and applications. GuardDuty doesn't generate findings for IP addresses that are included in IPSets. Only users from the administrator account can use this operation.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account that you want to create an IPSet for.
        name(str): The user-friendly name to identify the IPSet.  Allowed characters are alphanumerics, spaces, hyphens (-), and underscores (_).
        format_(str): The format of the file that contains the IPSet.
        location(str): The URI of the file that contains the IPSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key.
        activate(bool): A Boolean value that indicates whether GuardDuty is to start using the uploaded IPSet.
        client_token(str, optional): The idempotency token for the create request. Defaults to None.
        tags(Dict, optional): The tags to be added to a new IP set resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.ip_set_.create(
                ctx, detector_id=value, name=value, format_=value, location=value, activate=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.ip_set.create detector_id=value, name=value, format_=value, location=value, activate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="create_ip_set",
        op_kwargs={
            "DetectorId": detector_id,
            "Name": name,
            "Format": format_,
            "Location": location,
            "Activate": activate,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, detector_id: str, ip_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the IPSet specified by the ipSetId. IPSets are called trusted IP lists in the console user interface.

    Args:
        detector_id(str): The unique ID of the detector associated with the IPSet.
        ip_set_id(str): The unique ID of the IPSet to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.ip_set_.delete(
                ctx, detector_id=value, ip_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.ip_set.delete detector_id=value, ip_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="delete_ip_set",
        op_kwargs={"DetectorId": detector_id, "IpSetId": ip_set_id},
    )


async def get(hub, ctx, detector_id: str, ip_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the IPSet specified by the ipSetId.

    Args:
        detector_id(str): The unique ID of the detector that the IPSet is associated with.
        ip_set_id(str): The unique ID of the IPSet to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.ip_set_.get(ctx, detector_id=value, ip_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.ip_set.get detector_id=value, ip_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_ip_set",
        op_kwargs={"DetectorId": detector_id, "IpSetId": ip_set_id},
    )


async def list_all(
    hub, ctx, detector_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IPSets of the GuardDuty service specified by the detector ID. If you use this operation from a member account, the IPSets returned are the IPSets from the associated administrator account.

    Args:
        detector_id(str): The unique ID of the detector that the IPSet is associated with.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.ip_set_.list_all(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.ip_set.list_all detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_ip_sets",
        op_kwargs={
            "DetectorId": detector_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    detector_id: str,
    ip_set_id: str,
    name: str = None,
    location: str = None,
    activate: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the IPSet specified by the IPSet ID.

    Args:
        detector_id(str): The detectorID that specifies the GuardDuty service whose IPSet you want to update.
        ip_set_id(str): The unique ID that specifies the IPSet that you want to update.
        name(str, optional): The unique ID that specifies the IPSet that you want to update. Defaults to None.
        location(str, optional): The updated URI of the file that contains the IPSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key. Defaults to None.
        activate(bool, optional): The updated Boolean value that specifies whether the IPSet is active or not. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.ip_set_.update(
                ctx, detector_id=value, ip_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.ip_set.update detector_id=value, ip_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_ip_set",
        op_kwargs={
            "DetectorId": detector_id,
            "IpSetId": ip_set_id,
            "Name": name,
            "Location": location,
            "Activate": activate,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    plan_name: str,
    plan_type: str,
    product_id: str,
    provisioned_product_name: str,
    provisioning_artifact_id: str,
    idempotency_token: str,
    accept_language: str = None,
    notification_arns: List = None,
    path_id: str = None,
    provisioning_parameters: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a plan. A plan includes the list of resources to be created (when provisioning a new product) or modified (when updating a provisioned product) when the plan is executed. You can create one plan per provisioned product. To create a plan for an existing provisioned product, the product status must be AVAILBLE or TAINTED. To view the resource changes in the change set, use DescribeProvisionedProductPlan. To create or modify the provisioned product, use ExecuteProvisionedProductPlan.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        plan_name(str): The name of the plan.
        plan_type(str): The plan type.
        notification_arns(List, optional): Passed to CloudFormation. The SNS topic ARNs to which to publish stack-related events. Defaults to None.
        path_id(str, optional): The path identifier of the product. This value is optional if the product has a default path, and required if the product has more than one path. To list the paths for a product, use ListLaunchPaths. Defaults to None.
        product_id(str): The product identifier.
        provisioned_product_name(str): A user-friendly name for the provisioned product. This value must be unique for the AWS account and cannot be updated after the product is provisioned.
        provisioning_artifact_id(str): The identifier of the provisioning artifact.
        provisioning_parameters(List, optional): Parameters specified by the administrator that are required for provisioning the product. Defaults to None.
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.
        tags(List, optional): One or more tags. If the plan is for an existing provisioned product, the product must have a RESOURCE_UPDATE constraint with TagUpdatesOnProvisionedProduct set to ALLOWED to allow tag updates. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.plan.create(
                ctx,
                plan_name=value,
                plan_type=value,
                product_id=value,
                provisioned_product_name=value,
                provisioning_artifact_id=value,
                idempotency_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.plan.create plan_name=value, plan_type=value, product_id=value, provisioned_product_name=value, provisioning_artifact_id=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_provisioned_product_plan",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PlanName": plan_name,
            "PlanType": plan_type,
            "NotificationArns": notification_arns,
            "PathId": path_id,
            "ProductId": product_id,
            "ProvisionedProductName": provisioned_product_name,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "ProvisioningParameters": provisioning_parameters,
            "IdempotencyToken": idempotency_token,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, plan_id: str, accept_language: str = None, ignore_errors: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified plan.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        plan_id(str): The plan identifier.
        ignore_errors(bool, optional): If set to true, AWS Service Catalog stops managing the specified provisioned product even if it cannot delete the underlying resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.plan.delete(
                ctx, plan_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.plan.delete plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_provisioned_product_plan",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PlanId": plan_id,
            "IgnoreErrors": ignore_errors,
        },
    )


async def describe(
    hub,
    ctx,
    plan_id: str,
    accept_language: str = None,
    page_size: int = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the resource changes for the specified plan.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        plan_id(str): The plan identifier.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.plan.describe(
                ctx, plan_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.plan.describe plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_provisioned_product_plan",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PlanId": plan_id,
            "PageSize": page_size,
            "PageToken": page_token,
        },
    )


async def execute(
    hub, ctx, plan_id: str, idempotency_token: str, accept_language: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions or modifies a product based on the resource changes for the specified plan.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        plan_id(str): The plan identifier.
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.plan.execute(
                ctx, plan_id=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.plan.execute plan_id=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="execute_provisioned_product_plan",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PlanId": plan_id,
            "IdempotencyToken": idempotency_token,
        },
    )


async def list_all(
    hub,
    ctx,
    accept_language: str = None,
    provision_product_id: str = None,
    page_size: int = None,
    page_token: str = None,
    access_level_filter: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the plans for the specified provisioned product or all plans to which the user has access.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        provision_product_id(str, optional): The product identifier. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.
        access_level_filter(Dict, optional): The access level to use to obtain results. The default is User. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioned_product.plan.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioned_product.plan.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="list_provisioned_product_plans",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProvisionProductId": provision_product_id,
            "PageSize": page_size,
            "PageToken": page_token,
            "AccessLevelFilter": access_level_filter,
        },
    )
